export type Image = {
  src: string;
  alt?: string;
  caption?: string;
};

export type Link = {
  text: string;
  href: string;
};

export type Hero = {
  title?: string;
  text?: string;
  image?: Image;
  actions?: Link[];
};

export type Subscribe = {
  title?: string;
  text?: string;
  formUrl: string;
};

export type SiteConfig = {
  website: string;
  logo?: Image;
  title: string;
  subtitle?: string;
  description: string;
  image?: Image;
  headerNavLinks?: Link[];
  footerNavLinks?: Link[];
  socialLinks?: Link[];
  hero?: Hero;
  subscribe?: Subscribe;
  postsPerPage?: number;
  projectsPerPage?: number;
};

const siteConfig: SiteConfig = {
  website: "https://readings.tiff.ws",
  title: "tiff on books",
  subtitle: "notes from books i've read",
  description: "from the brain of tiff on software",
  // image: {
  //     src: '/dante-preview.jpg',
  //     alt: 'Dante - Astro.js and Tailwind CSS theme'
  // },
  headerNavLinks: [
    {
      text: "Home",
      href: "/",
    },
    {
      text: "Blog",
      href: "/blog",
    },
    {
      text: "Tags",
      href: "/tags",
    },
  ],
  footerNavLinks: [
    {
      text: "About",
      href: "/about",
    },
  ],
  socialLinks: [
    {
      text: "Matrix",
      href: "https://matrix.to/#/@100pdatcat:matrix.org",
    },
    {
      text: "Signal",
      href:
        "https://signal.me/#eu/Bdd-Fbkm5vTYvnUtpmCVtw-gGndYPlBHF_O4XWypX-JYwXf0r7dIpIdbWa2QnN6F",
    },
    {
      text: "Email",
      href: "mailto:hithere@tiff.run",
    },
  ],
  hero: {
    title: "Hi There & Welcome to My Corner of the Web!",
    text:
      "I'm **Ethan Donovan**, a web developer at Amazing Studio, dedicated to the realms of collaboration and artificial intelligence. My approach involves embracing intuition, conducting just enough research, and leveraging aesthetics as a catalyst for exceptional products. I have a profound appreciation for top-notch software, visual design, and the principles of product-led growth. Feel free to explore some of my coding endeavors on <a href='https://github.com/JustGoodUI/dante-astro-theme'>GitHub</a> or follow me on <a href='https://twitter.com/justgoodui'>Twitter/X</a>.",
    image: {
      src: "/hero.jpeg",
      alt: "A person sitting at a desk in front of a computer",
    },
    actions: [
      {
        text: "Get in Touch",
        href: "/contact",
      },
    ],
  },
  postsPerPage: 8,
  projectsPerPage: 8,
};

export default siteConfig;
